/**
 * @file align_left_shift.h
 *
 * @author  Matthew Woehlke
 * @license GPL v2+
 */

#ifndef ALIGN_EIGEN_COMMA_INIT_H_INCLUDED
#define ALIGN_EIGEN_COMMA_INIT_H_INCLUDED

//! Align comma-separated expressions following left shift operator '<<'
void align_eigen_comma_init();

#endif /* ALIGN_EIGEN_COMMA_INIT_H_INCLUDED */
